# django-grainy

[![PyPI](https://img.shields.io/pypi/v/django-grainy.svg?maxAge=60)](https://pypi.python.org/pypi/django-grainy)
[![Travis CI](https://img.shields.io/travis/20c/django-grainy.svg?maxAge=60)](https://travis-ci.org/20c/django-grainy)
[![Code Health](https://landscape.io/github/20c/django-grainy/master/landscape.svg?style=flat)](https://landscape.io/github/20c/django-grainy/master)
[![Codecov](https://img.shields.io/codecov/c/github/20c/django-grainy/master.svg?maxAge=60)](https://codecov.io/github/20c/django-grainy)
[![Requires.io](https://img.shields.io/requires/github/20c/django-grainy.svg?maxAge=60)](https://requires.io/github/20c/django-grainy/requirements)

Granular permissions for django

## Documentation

http://django-grainy.readthedocs.io/en/latest/
